@@ -3,15 +3,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': './Parser/asdl_c.py',
- 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
- 'AST_ASDL': './Parser/Python.asdl',
- 'AST_C': 'Python/Python-ast.c',
- 'AST_C_DIR': 'Python',
- 'AST_H': 'Include/Python-ast.h',
- 'AST_H_DIR': 'Include',
  'ATHEOS_THREADS': 0,
- 'BASECFLAGS': '-fno-strict-aliasing',
+ 'BASECFLAGS': '-fno-strict-aliasing -OPT:Olimit=0',
  'BASEMODLIBS': '',
  'BEOS_THREADS': 0,
  'BINDIR': '/usr/local/bin',
@@ -22,15 +15,15 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BUILDPYTHON': 'python',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC',
+ 'CFLAGS': '-fno-strict-aliasing -OPT:Olimit=0 -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.13/Python-2.7.13' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.14/Python-2.7.14' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd6:lib-tk:lib-old',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.13/Python-2.7.13/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.13/Python-2.7.13/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-2.7.14/Python-2.7.14/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-2.7.14/Python-2.7.14/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
@@ -61,11 +54,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
+ 'GITBRANCH': '',
+ 'GITTAG': '',
+ 'GITVERSION': '',
  'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'yes',
- 'GRAMMAR_C': 'Python/graminit.c',
- 'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': './Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -139,7 +132,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FTRUNCATE': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
- 'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_ASM_FOR_X87': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -307,6 +300,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
+ 'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
  'HAVE_SYS_SOCKET_H': 1,
@@ -353,19 +347,16 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HGBRANCH': '',
- 'HGTAG': '',
- 'HGVERSION': '',
- 'HOST_GNU_TYPE': 'i386-unknown-openbsd6.1',
+ 'HOST_GNU_TYPE': 'arm-unknown-openbsd6.3',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python2.7',
- 'INSTALL': '/usr/obj/ports/Python-2.7.13/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.13/bin/install -c  -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.13/bin/install -c -s  -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.13/bin/install -c  -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.13/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-2.7.14/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.14/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.14/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.14/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.14/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.0.0',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
  'LDFLAGS': '-L/usr/local/lib/',
@@ -415,9 +406,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPCODETARGETGEN': '\\',
- 'OPCODETARGETGEN_FILES': '\\',
- 'OPCODETARGETS_H': '\\',
  'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -452,9 +440,10 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-openbsd6:lib-tk:lib-old',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC -I. -IInclude -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -OPT:Olimit=0 -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC -I. -IInclude -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'unsigned short',
@@ -466,7 +455,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.13/Python-2.7.13',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.14/Python-2.7.14',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -481,7 +470,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 12,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -494,23 +483,22 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SRCDIRS': 'Parser Objects Python Modules',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc Demo',
- 'SVNVERSION': 'echo Unversioned directory',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TANH_PRESERVES_ZERO_SIGN': 0,
+ 'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.13/Python-2.7.13 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.14/Python-2.7.14 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -533,13 +521,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 1,
+ 'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-2.7.13/Python-2.7.13',
- 'abs_srcdir': '/usr/obj/ports/Python-2.7.13/Python-2.7.13',
- 'build': 'i386-unknown-openbsd6.1',
+ 'abs_builddir': '/usr/obj/ports/Python-2.7.14/Python-2.7.14',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.14/Python-2.7.14',
+ 'build': 'arm-unknown-openbsd6.3',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'i386-unknown-openbsd6.1',
+ 'host': 'arm-unknown-openbsd6.3',
  'prefix': '/usr/local',
  'srcdir': '.'}
